@@ -7,6 +7,10 @@ from django.db import models
 
 class Migration(SchemaMigration):
 
+    depends_on = (
+        ('cms', '0001_initial.py'),
+    )
+
     def forwards(self, orm):
         # Adding model 'Text'
         db.create_table('cmsplugin_text', (
@@ -50,4 +54,4 @@ class Migration(SchemaMigration):
         }
     }
 
-    complete_apps = ['djangocms_text_ckeditor']
\ No newline at end of file
+    complete_apps = ['djangocms_text_ckeditor']
